==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/LinkedAssociationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.AssociationSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOneSideSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOtherSideSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsLinkSet;
import io.ciera.tool.sql.ooaofooa.association.LinkedAssociation;
import io.ciera.tool.sql.ooaofooa.association.LinkedAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.AssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsAssociatedOneSideSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsAssociatedOtherSideSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsLinkSetImpl;

import java.util.Arrays;
import java.util.List;


public class LinkedAssociationSetImpl extends InstanceSet<LinkedAssociationSet,LinkedAssociation> implements LinkedAssociationSet {

    // attributes
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( LinkedAssociation linkedassociation : this ) linkedassociation.setRel_ID( ref_Rel_ID );
    }


    // selections
    @Override
    public AssociationSet R206_is_a_Association() throws XtumlException {
        AssociationSet associationset = new AssociationSetImpl();
        for ( LinkedAssociation linkedassociation : this ) associationset.add( linkedassociation.R206_is_a_Association() );
        return associationset;
    }
    @Override
    public ClassAsAssociatedOneSideSet R209_relates_ClassAsAssociatedOneSide() throws XtumlException {
        ClassAsAssociatedOneSideSet classasassociatedonesideset = new ClassAsAssociatedOneSideSetImpl();
        for ( LinkedAssociation linkedassociation : this ) classasassociatedonesideset.add( linkedassociation.R209_relates_ClassAsAssociatedOneSide() );
        return classasassociatedonesideset;
    }
    @Override
    public ClassAsAssociatedOtherSideSet R210_relates_ClassAsAssociatedOtherSide() throws XtumlException {
        ClassAsAssociatedOtherSideSet classasassociatedothersideset = new ClassAsAssociatedOtherSideSetImpl();
        for ( LinkedAssociation linkedassociation : this ) classasassociatedothersideset.add( linkedassociation.R210_relates_ClassAsAssociatedOtherSide() );
        return classasassociatedothersideset;
    }
    @Override
    public ClassAsLinkSet R211_uses_a_formalizer_ClassAsLink() throws XtumlException {
        ClassAsLinkSet classaslinkset = new ClassAsLinkSetImpl();
        for ( LinkedAssociation linkedassociation : this ) classaslinkset.add( linkedassociation.R211_uses_a_formalizer_ClassAsLink() );
        return classaslinkset;
    }


    @Override
    public LinkedAssociation nullElement() {
        return LinkedAssociationImpl.EMPTY_LINKEDASSOCIATION;
    }

    @Override
    public LinkedAssociationSet emptySet() {
      return new LinkedAssociationSetImpl();
    }

    @Override
    public LinkedAssociationSet value() {
        return this;
    }

    @Override
    public List<LinkedAssociation> elements() {
        return Arrays.asList(toArray(new LinkedAssociation[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/LinkedAssociationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.AssociationSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOneSideSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOtherSideSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsLinkSet;
import io.ciera.tool.sql.ooaofooa.association.LinkedAssociation;
import io.ciera.tool.sql.ooaofooa.association.LinkedAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.AssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsAssociatedOneSideSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsAssociatedOtherSideSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsLinkSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class LinkedAssociationSetImpl extends InstanceSet<LinkedAssociationSet,LinkedAssociation> implements LinkedAssociationSet {

    public LinkedAssociationSetImpl() {
    }

    public LinkedAssociationSetImpl(Comparator<? super LinkedAssociation> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( LinkedAssociation linkedassociation : this ) linkedassociation.setRel_ID( ref_Rel_ID );
    }


    // selections
    @Override
    public AssociationSet R206_is_a_Association() throws XtumlException {
        AssociationSet associationset = new AssociationSetImpl();
        for ( LinkedAssociation linkedassociation : this ) associationset.add( linkedassociation.R206_is_a_Association() );
        return associationset;
    }
    @Override
    public ClassAsAssociatedOneSideSet R209_relates_ClassAsAssociatedOneSide() throws XtumlException {
        ClassAsAssociatedOneSideSet classasassociatedonesideset = new ClassAsAssociatedOneSideSetImpl();
        for ( LinkedAssociation linkedassociation : this ) classasassociatedonesideset.add( linkedassociation.R209_relates_ClassAsAssociatedOneSide() );
        return classasassociatedonesideset;
    }
    @Override
    public ClassAsAssociatedOtherSideSet R210_relates_ClassAsAssociatedOtherSide() throws XtumlException {
        ClassAsAssociatedOtherSideSet classasassociatedothersideset = new ClassAsAssociatedOtherSideSetImpl();
        for ( LinkedAssociation linkedassociation : this ) classasassociatedothersideset.add( linkedassociation.R210_relates_ClassAsAssociatedOtherSide() );
        return classasassociatedothersideset;
    }
    @Override
    public ClassAsLinkSet R211_uses_a_formalizer_ClassAsLink() throws XtumlException {
        ClassAsLinkSet classaslinkset = new ClassAsLinkSetImpl();
        for ( LinkedAssociation linkedassociation : this ) classaslinkset.add( linkedassociation.R211_uses_a_formalizer_ClassAsLink() );
        return classaslinkset;
    }


    @Override
    public LinkedAssociation nullElement() {
        return LinkedAssociationImpl.EMPTY_LINKEDASSOCIATION;
    }

    @Override
    public LinkedAssociationSet emptySet() {
      return new LinkedAssociationSetImpl();
    }

    @Override
    public LinkedAssociationSet emptySet(Comparator<? super LinkedAssociation> comp) {
      return new LinkedAssociationSetImpl(comp);
    }

    @Override
    public LinkedAssociationSet value() {
        return this;
    }

    @Override
    public List<LinkedAssociation> elements() {
        return Arrays.asList(toArray(new LinkedAssociation[0]));
    }

}
